# About fluopenslide1

With this library, you are able to open .czi files and display regions of it. It is supposed to compensate the fact that Openslide did not support .czi files.


It is mainly based on the aicspylibczi library, whom documentation is available on <https://github.com/AllenCellModeling/aicspylibczi>.

# Installation

You can install it with `pip install`. When you are in your terminal , just use `pip install fluopenslide1` and it will install the whole library. You can then use it at your convenience.

You can also install it directly from GitHut by downloading it here : <https://github.com/LRobach/fluopenslide1/archive/refs/heads/master.zip>.

# Documentation

Its documentation is available on <https://github.com/LRobach/fluopenslide1>.

# Carefull with fluopenslide package

Be carefull. The fluopenslide package is not working, you have to install the fluopenslide1 one.
